# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKStatisticsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkHistogramToLogProbabilityImageFilterPython
else:
    import _itkHistogramToLogProbabilityImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImageSourcePython
import itk.itkImagePython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkPointPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkRGBAPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageRegionPython
import itk.ITKCommonBasePython
import itk.itkIndexPython
import itk.itkRGBPixelPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageSourceCommonPython
import itk.itkHistogramPython
import itk.itkArrayPython
import itk.itkSamplePython

def itkHistogramToLogProbabilityImageFilterHDIF2_Superclass_New():
    return itkHistogramToLogProbabilityImageFilterHDIF2_Superclass.New()

class itkHistogramToLogProbabilityImageFilterHDIF2_Superclass(itk.itkImageSourcePython.itkImageSourceIF2):
    r"""Proxy of C++ itkHistogramToLogProbabilityImageFilterHDIF2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToLogProbabilityImageFilterHDIF2_Superclass_Pointer"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToLogProbabilityImageFilterHDIF2_Superclass_Pointer"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF2_Superclass_Clone(self)

    def SetInput(self, input):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkHistogramD const *

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF2_Superclass_SetInput(self, input)

    def GetInput(self):
        r"""GetInput(self) -> itkHistogramD"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF2_Superclass_GetInput(self)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Function::HistogramLogProbabilityFunction< unsigned long,float > const &

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF2_Superclass_SetFunctor(self, functor)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Function::HistogramLogProbabilityFunction< unsigned long,float >
        GetFunctor(self) -> itk::Function::HistogramLogProbabilityFunction< unsigned long,float > const &
        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF2_Superclass_GetFunctor(self, *args)

    def SetTotalFrequency(self, n):
        r"""
        SetTotalFrequency(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF2_Superclass_SetTotalFrequency(self, n)
    __swig_destroy__ = _itkHistogramToLogProbabilityImageFilterPython.delete_itkHistogramToLogProbabilityImageFilterHDIF2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToLogProbabilityImageFilterHDIF2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToLogProbabilityImageFilterHDIF2_Superclass

        Create a new object of the class itkHistogramToLogProbabilityImageFilterHDIF2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToLogProbabilityImageFilterHDIF2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToLogProbabilityImageFilterHDIF2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToLogProbabilityImageFilterHDIF2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToLogProbabilityImageFilterHDIF2_Superclass in _itkHistogramToLogProbabilityImageFilterPython:
_itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF2_Superclass_swigregister(itkHistogramToLogProbabilityImageFilterHDIF2_Superclass)

def itkHistogramToLogProbabilityImageFilterHDIF3_Superclass_New():
    return itkHistogramToLogProbabilityImageFilterHDIF3_Superclass.New()

class itkHistogramToLogProbabilityImageFilterHDIF3_Superclass(itk.itkImageSourcePython.itkImageSourceIF3):
    r"""Proxy of C++ itkHistogramToLogProbabilityImageFilterHDIF3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToLogProbabilityImageFilterHDIF3_Superclass_Pointer"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToLogProbabilityImageFilterHDIF3_Superclass_Pointer"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF3_Superclass_Clone(self)

    def SetInput(self, input):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkHistogramD const *

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF3_Superclass_SetInput(self, input)

    def GetInput(self):
        r"""GetInput(self) -> itkHistogramD"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF3_Superclass_GetInput(self)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Function::HistogramLogProbabilityFunction< unsigned long,float > const &

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF3_Superclass_SetFunctor(self, functor)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Function::HistogramLogProbabilityFunction< unsigned long,float >
        GetFunctor(self) -> itk::Function::HistogramLogProbabilityFunction< unsigned long,float > const &
        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF3_Superclass_GetFunctor(self, *args)

    def SetTotalFrequency(self, n):
        r"""
        SetTotalFrequency(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF3_Superclass_SetTotalFrequency(self, n)
    __swig_destroy__ = _itkHistogramToLogProbabilityImageFilterPython.delete_itkHistogramToLogProbabilityImageFilterHDIF3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToLogProbabilityImageFilterHDIF3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToLogProbabilityImageFilterHDIF3_Superclass

        Create a new object of the class itkHistogramToLogProbabilityImageFilterHDIF3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToLogProbabilityImageFilterHDIF3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToLogProbabilityImageFilterHDIF3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToLogProbabilityImageFilterHDIF3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToLogProbabilityImageFilterHDIF3_Superclass in _itkHistogramToLogProbabilityImageFilterPython:
_itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF3_Superclass_swigregister(itkHistogramToLogProbabilityImageFilterHDIF3_Superclass)

def itkHistogramToLogProbabilityImageFilterHFIF2_Superclass_New():
    return itkHistogramToLogProbabilityImageFilterHFIF2_Superclass.New()

class itkHistogramToLogProbabilityImageFilterHFIF2_Superclass(itk.itkImageSourcePython.itkImageSourceIF2):
    r"""Proxy of C++ itkHistogramToLogProbabilityImageFilterHFIF2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToLogProbabilityImageFilterHFIF2_Superclass_Pointer"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToLogProbabilityImageFilterHFIF2_Superclass_Pointer"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF2_Superclass_Clone(self)

    def SetInput(self, input):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkHistogramF const *

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF2_Superclass_SetInput(self, input)

    def GetInput(self):
        r"""GetInput(self) -> itkHistogramF"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF2_Superclass_GetInput(self)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Function::HistogramLogProbabilityFunction< unsigned long,float > const &

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF2_Superclass_SetFunctor(self, functor)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Function::HistogramLogProbabilityFunction< unsigned long,float >
        GetFunctor(self) -> itk::Function::HistogramLogProbabilityFunction< unsigned long,float > const &
        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF2_Superclass_GetFunctor(self, *args)

    def SetTotalFrequency(self, n):
        r"""
        SetTotalFrequency(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF2_Superclass_SetTotalFrequency(self, n)
    __swig_destroy__ = _itkHistogramToLogProbabilityImageFilterPython.delete_itkHistogramToLogProbabilityImageFilterHFIF2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToLogProbabilityImageFilterHFIF2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToLogProbabilityImageFilterHFIF2_Superclass

        Create a new object of the class itkHistogramToLogProbabilityImageFilterHFIF2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToLogProbabilityImageFilterHFIF2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToLogProbabilityImageFilterHFIF2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToLogProbabilityImageFilterHFIF2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToLogProbabilityImageFilterHFIF2_Superclass in _itkHistogramToLogProbabilityImageFilterPython:
_itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF2_Superclass_swigregister(itkHistogramToLogProbabilityImageFilterHFIF2_Superclass)

def itkHistogramToLogProbabilityImageFilterHFIF3_Superclass_New():
    return itkHistogramToLogProbabilityImageFilterHFIF3_Superclass.New()

class itkHistogramToLogProbabilityImageFilterHFIF3_Superclass(itk.itkImageSourcePython.itkImageSourceIF3):
    r"""Proxy of C++ itkHistogramToLogProbabilityImageFilterHFIF3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToLogProbabilityImageFilterHFIF3_Superclass_Pointer"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToLogProbabilityImageFilterHFIF3_Superclass_Pointer"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF3_Superclass_Clone(self)

    def SetInput(self, input):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkHistogramF const *

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF3_Superclass_SetInput(self, input)

    def GetInput(self):
        r"""GetInput(self) -> itkHistogramF"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF3_Superclass_GetInput(self)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Function::HistogramLogProbabilityFunction< unsigned long,float > const &

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF3_Superclass_SetFunctor(self, functor)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Function::HistogramLogProbabilityFunction< unsigned long,float >
        GetFunctor(self) -> itk::Function::HistogramLogProbabilityFunction< unsigned long,float > const &
        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF3_Superclass_GetFunctor(self, *args)

    def SetTotalFrequency(self, n):
        r"""
        SetTotalFrequency(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF3_Superclass_SetTotalFrequency(self, n)
    __swig_destroy__ = _itkHistogramToLogProbabilityImageFilterPython.delete_itkHistogramToLogProbabilityImageFilterHFIF3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToLogProbabilityImageFilterHFIF3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToLogProbabilityImageFilterHFIF3_Superclass

        Create a new object of the class itkHistogramToLogProbabilityImageFilterHFIF3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToLogProbabilityImageFilterHFIF3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToLogProbabilityImageFilterHFIF3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToLogProbabilityImageFilterHFIF3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToLogProbabilityImageFilterHFIF3_Superclass in _itkHistogramToLogProbabilityImageFilterPython:
_itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF3_Superclass_swigregister(itkHistogramToLogProbabilityImageFilterHFIF3_Superclass)

def itkHistogramToLogProbabilityImageFilterHDIF2_New():
    return itkHistogramToLogProbabilityImageFilterHDIF2.New()

class itkHistogramToLogProbabilityImageFilterHDIF2(itkHistogramToLogProbabilityImageFilterHDIF2_Superclass):
    r"""Proxy of C++ itkHistogramToLogProbabilityImageFilterHDIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToLogProbabilityImageFilterHDIF2_Pointer"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToLogProbabilityImageFilterHDIF2_Pointer"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF2_Clone(self)
    __swig_destroy__ = _itkHistogramToLogProbabilityImageFilterPython.delete_itkHistogramToLogProbabilityImageFilterHDIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToLogProbabilityImageFilterHDIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToLogProbabilityImageFilterHDIF2

        Create a new object of the class itkHistogramToLogProbabilityImageFilterHDIF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToLogProbabilityImageFilterHDIF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToLogProbabilityImageFilterHDIF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToLogProbabilityImageFilterHDIF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToLogProbabilityImageFilterHDIF2 in _itkHistogramToLogProbabilityImageFilterPython:
_itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF2_swigregister(itkHistogramToLogProbabilityImageFilterHDIF2)

def itkHistogramToLogProbabilityImageFilterHDIF3_New():
    return itkHistogramToLogProbabilityImageFilterHDIF3.New()

class itkHistogramToLogProbabilityImageFilterHDIF3(itkHistogramToLogProbabilityImageFilterHDIF3_Superclass):
    r"""Proxy of C++ itkHistogramToLogProbabilityImageFilterHDIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToLogProbabilityImageFilterHDIF3_Pointer"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToLogProbabilityImageFilterHDIF3_Pointer"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF3_Clone(self)
    __swig_destroy__ = _itkHistogramToLogProbabilityImageFilterPython.delete_itkHistogramToLogProbabilityImageFilterHDIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToLogProbabilityImageFilterHDIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToLogProbabilityImageFilterHDIF3

        Create a new object of the class itkHistogramToLogProbabilityImageFilterHDIF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToLogProbabilityImageFilterHDIF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToLogProbabilityImageFilterHDIF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToLogProbabilityImageFilterHDIF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToLogProbabilityImageFilterHDIF3 in _itkHistogramToLogProbabilityImageFilterPython:
_itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHDIF3_swigregister(itkHistogramToLogProbabilityImageFilterHDIF3)

def itkHistogramToLogProbabilityImageFilterHFIF2_New():
    return itkHistogramToLogProbabilityImageFilterHFIF2.New()

class itkHistogramToLogProbabilityImageFilterHFIF2(itkHistogramToLogProbabilityImageFilterHFIF2_Superclass):
    r"""Proxy of C++ itkHistogramToLogProbabilityImageFilterHFIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToLogProbabilityImageFilterHFIF2_Pointer"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToLogProbabilityImageFilterHFIF2_Pointer"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF2_Clone(self)
    __swig_destroy__ = _itkHistogramToLogProbabilityImageFilterPython.delete_itkHistogramToLogProbabilityImageFilterHFIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToLogProbabilityImageFilterHFIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToLogProbabilityImageFilterHFIF2

        Create a new object of the class itkHistogramToLogProbabilityImageFilterHFIF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToLogProbabilityImageFilterHFIF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToLogProbabilityImageFilterHFIF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToLogProbabilityImageFilterHFIF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToLogProbabilityImageFilterHFIF2 in _itkHistogramToLogProbabilityImageFilterPython:
_itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF2_swigregister(itkHistogramToLogProbabilityImageFilterHFIF2)

def itkHistogramToLogProbabilityImageFilterHFIF3_New():
    return itkHistogramToLogProbabilityImageFilterHFIF3.New()

class itkHistogramToLogProbabilityImageFilterHFIF3(itkHistogramToLogProbabilityImageFilterHFIF3_Superclass):
    r"""Proxy of C++ itkHistogramToLogProbabilityImageFilterHFIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToLogProbabilityImageFilterHFIF3_Pointer"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToLogProbabilityImageFilterHFIF3_Pointer"""
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF3_Clone(self)
    __swig_destroy__ = _itkHistogramToLogProbabilityImageFilterPython.delete_itkHistogramToLogProbabilityImageFilterHFIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToLogProbabilityImageFilterHFIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToLogProbabilityImageFilterHFIF3

        Create a new object of the class itkHistogramToLogProbabilityImageFilterHFIF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToLogProbabilityImageFilterHFIF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToLogProbabilityImageFilterHFIF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToLogProbabilityImageFilterHFIF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToLogProbabilityImageFilterHFIF3 in _itkHistogramToLogProbabilityImageFilterPython:
_itkHistogramToLogProbabilityImageFilterPython.itkHistogramToLogProbabilityImageFilterHFIF3_swigregister(itkHistogramToLogProbabilityImageFilterHFIF3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def histogram_to_image_filter(*args,  functor=..., total_frequency: int=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for HistogramToImageFilter"""
    import itk

    kwarg_typehints = { 'functor':functor,'total_frequency':total_frequency }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.HistogramToImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def histogram_to_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKStatistics.HistogramToImageFilter
    histogram_to_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    histogram_to_image_filter.__doc__ = filter_object.__doc__

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def histogram_to_log_probability_image_filter(*args,  functor=..., total_frequency: int=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for HistogramToLogProbabilityImageFilter"""
    import itk

    kwarg_typehints = { 'functor':functor,'total_frequency':total_frequency }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.HistogramToLogProbabilityImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def histogram_to_log_probability_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKStatistics.HistogramToLogProbabilityImageFilter
    histogram_to_log_probability_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    histogram_to_log_probability_image_filter.__doc__ = filter_object.__doc__



